<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <!-- Open Graph -->
    <meta property="og:url" content="{{ meta.url }}">
    <meta property="og:type" content="website">
    <meta property="og:title" content="My Website">
    <meta property="og:description" content="Description for my website.">
    <meta property="og:image" content="https://example.com/img/apple.jpg">

    <!-- Bootstrap -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-Zenh87qX5JnK2Jl0vWa8Ck2rdkQ2Bzep5IDxbcnCeuOxjzrPF/et3URy9Bv1WTRi" crossorigin="anonymous">

    <!-- Highlightjs -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.5.0/styles/github-dark.min.css">
    <script src="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.5.0/highlight.min.js"></script>
    <script>hljs.highlightAll();</script>

    <!-- Styles -->
    <link rel="stylesheet" href="{% if meta.category != '_posts' %}../../{% else %}../{% endif %}styles.css">

    <title>My Website</title>
</head>
<body>
<div class="container">
    <div class="row">
        <div class="col-md">

            <h2 class="mt-4">{{ meta.title }}</h2>

            <h6>Written on {{ meta.date }}</h6>

            {{ content }}

        </div>
    </div>
</div>
</body>
</html>
