body {
    background-color: lightgrey;
}

a {
    text-decoration: none;
}

a:hover {
    background-color: white;
    color: blue;
}

h1 {
    margin-top: 2rem;
}

.container {
    max-width: 700px;
}